Index: src/deoptimizer.cc |
=================================================================== |
--- src/deoptimizer.cc (revision 6199) |
+++ src/deoptimizer.cc (working copy) |
@@ -618,17 +618,17 @@ |
} |
case Translation::ARGUMENTS_OBJECT: { |
// Use the hole value as a sentinel and fill in the arguments object |
// after the deoptimized frame is built. |
ASSERT(frame_index == 0); // Only supported for first frame. |
if (FLAG_trace_deopt) { |
PrintF(" 0x%08" V8PRIxPTR ": [top + %d] <- ", |
output_[frame_index]->GetTop() + output_offset, |
output_offset); |
- Heap::the_hole_value()->ShortPrint(); |
+ Heap::arguments_marker()->ShortPrint(); |
PrintF(" ; arguments object\n"); |
} |
- intptr_t value = reinterpret_cast<intptr_t>(Heap::the_hole_value()); |
+ intptr_t value = reinterpret_cast<intptr_t>(Heap::arguments_marker()); |
output_[frame_index]->SetFrameSlot(output_offset, value); |
return; |
} |
@@ -618,17 +618,17 @@ |
} |
case Translation::ARGUMENTS_OBJECT: { |
- // Use the hole value as a sentinel and fill in the arguments object |
- // after the deoptimized frame is built. |
+ // Use the arguments marker value as a sentinel and fill in the arguments |
+ // object after the deoptimized frame is built. |
ASSERT(frame_index == 0); // Only supported for first frame. |
if (FLAG_trace_deopt) { |